pub struct MatchParamCmpIOperation<'c> { /* private fields */ }Expand description
A match.param.cmpi operation. Matches if two parameter lists are associated with the same value.
Succeeds if all of the co-indexed values associated with the given parameters relate as specified by the predicate (greater than, less than, equal to, or their combinations). Comparison treats all values as signed. Produces a silenceable failure otherwise.
Implementations
Sourceimpl<'c> MatchParamCmpIOperation<'c>
impl<'c> MatchParamCmpIOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> MatchParamCmpIOperationBuilder<'c, Unset, Unset, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> MatchParamCmpIOperationBuilder<'c, Unset, Unset, Unset>
Creates a builder.
pub fn param(&self) -> Result<Value<'c, '_>, Error>
pub fn reference(&self) -> Result<Value<'c, '_>, Error>
pub fn predicate(&self) -> Result<Attribute<'c>, Error>
pub fn set_predicate(&mut self, value: Attribute<'c>)